summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorHenri Sara <henri.sara@itmill.com>2011-06-14 08:45:41 +0000
committerHenri Sara <henri.sara@itmill.com>2011-06-14 08:45:41 +0000
commit6566c5eb6f87e709ab6dc7099df084eec840558c (patch)
tree44a2642313b28195c6499bcd21b357b2b9857595 /src
parent18b6f32562a706059950c1d609522daa2cd5297d (diff)
downloadvaadin-framework-6566c5eb6f87e709ab6dc7099df084eec840558c.tar.gz
vaadin-framework-6566c5eb6f87e709ab6dc7099df084eec840558c.zip
#4125 minor renames in comments and exception messages
svn changeset:19362/svn branch:6.6
Diffstat (limited to 'src')
-rw-r--r--src/com/vaadin/ui/MenuBar.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/com/vaadin/ui/MenuBar.java b/src/com/vaadin/ui/MenuBar.java
index b04b38175c..f8fbf91712 100644
--- a/src/com/vaadin/ui/MenuBar.java
+++ b/src/com/vaadin/ui/MenuBar.java
@@ -125,7 +125,7 @@ public class MenuBar extends AbstractComponent {
}
if (item.isCheckable()) {
// if the "checked" attribute is present (either true or false),
// the item is selectable
target.addAttribute(VMenuBar.ATTRIBUTE_CHECKED,
item.isChecked());
}
@@ -518,7 +518,7 @@ public class MenuBar extends AbstractComponent {
* @param command
* the command for the menu item
* @throws IllegalStateException
* If the item is selectable and thus cannot have children.
*/
public MenuBar.MenuItem addItem(String caption, Resource icon,
MenuBar.Command command) throws IllegalStateException {
@@ -528,7 +528,7 @@ public class MenuBar extends AbstractComponent {
}
if (isCheckable()) {
throw new IllegalStateException(
- "A selectable item cannot have children");
+ "A checkable item cannot have children");
}
if (caption == null) {
throw new IllegalArgumentException("Caption cannot be null");
@@ -563,14 +563,14 @@ public class MenuBar extends AbstractComponent {
* @param itemToAddBefore
* the item that will be after the new item
* @throws IllegalStateException
* If the item is selectable and thus cannot have children.
*/
public MenuBar.MenuItem addItemBefore(String caption, Resource icon,
MenuBar.Command command, MenuBar.MenuItem itemToAddBefore)
throws IllegalStateException {
if (isCheckable()) {
throw new IllegalStateException(
- "A selectable item cannot have children");
+ "A checkable item cannot have children");
}
MenuItem newItem = null;
@@ -125,7 +125,7 @@ public class MenuBar extends AbstractComponent {
if (item.isCheckable()) {
// if the "checked" attribute is present (either true or false),
- // the item is selectable
+ // the item is checkable
target.addAttribute(VMenuBar.ATTRIBUTE_CHECKED,
item.isChecked());
@@ -518,7 +518,7 @@ public class MenuBar extends AbstractComponent {
* the command for the menu item
* @throws IllegalStateException
- * If the item is selectable and thus cannot have children.
+ * If the item is checkable and thus cannot have children.
*/
public MenuBar.MenuItem addItem(String caption, Resource icon,
@@ -563,14 +563,14 @@ public class MenuBar extends AbstractComponent {
* the item that will be after the new item
* @throws IllegalStateException
- * If the item is selectable and thus cannot have children.
+ * If the item is checkable and thus cannot have children.
*/
public MenuBar.MenuItem addItemBefore(String caption, Resource icon,